@@ -12,6 +12,7 @@ my (undef, undef, $init_meta) = Moose::Exporter->build_import_methods(
     )],
     with_meta => [qw(
         has
+        has_non_attribute_mapping
     )],
     class_metaroles => {
         class => [
@@ -34,5 +35,10 @@ sub init_meta {
     $class->$init_meta(%p);
 }
 
+sub has_non_attribute_mapping {
+    my ($self,$mapping) = @_;
+    $self->non_attribute_mapping($mapping);
+}
+
 1;
 
