@@ -2,7 +2,6 @@ package Test::Elasticsearch::Model::Document::Role::Metaclass;
 
 use Test::Class::Most parent => 'Test';
 
-
 sub basics : Tests(no_plan) {
     my $self          = shift;
     my $document_meta = TestModel::DocumentTypeA->meta;
@@ -16,6 +15,7 @@ sub basics : Tests(no_plan) {
         add_property
         mapping
         shortname
+        non_attribute_mapping
     /);
 }
 
@@ -28,4 +28,18 @@ sub shortname : Tests(no_plan) {
     }
 }
 
+sub non_attribute_mapping :Tests(no_plan) {
+    my $self = shift;
+    my $model = TestModel->new;
+    my $index = $model->index('c');
+    my $expected = {
+        _source => {
+            excludes => [qw/grass_field/],
+        }
+    };
+    my $got = $index->type_meta->non_attribute_mapping;
+    is_deeply($got,$expected, "My non_attribute_mappings were correctly inserted into my document meta class");
+}
+
+
 1;
